@@ -228,9 +228,15 @@ def parse_ship(p: Product, selector: parsel.Selector = None):
 
 
 def parse_sold(p: Product, selector: parsel.Selector = None):
-    p.sold = selector.xpath(
+    sold = selector.xpath(
         "normalize-space(//span[contains(text(), 'Sold by:')]/following-sibling::*[1]/text())"
     ).get()
+    sold = sold or tabular_buy_box_container(selector, "Sold by")
+    sold = sold or selector.xpath("//a[@id='sellerProfileTriggerId']/text()").get("")
+    if sold == "":
+        p.sold = None
+    else:
+        p.sold = sold
 
 
 def parse_offers(p: Product, selector: parsel.Selector = None):
@@ -246,7 +252,7 @@ def parse_offers(p: Product, selector: parsel.Selector = None):
 def parse_delivery(p: Product, selector: parsel.Selector = None):
     delivery = selector.xpath("string(//div[@id='contextualIngressPtLabel_deliveryShortLine'])").get()
     delivery = delivery or selector.xpath("normalize-space(//span[@id='glow-ingress-line2']/text())").get()
-    if delivery is None:
+    if delivery is None or delivery == "":
         p.delivery = None
         return
     if delivery in ["Select delivery location", "Select your address"]:
@@ -285,7 +291,10 @@ def parse_description(p: Product, selector: parsel.Selector = None):
 
 def parse_title(p: Product, selector: parsel.Selector = None):
     title = selector.xpath("normalize-space(//span[@id='productTitle']/text())").get()
-    p.title = title
+    if title == "":
+        p.title = None
+    else:
+        p.title = title
 
 
 def parse_size(p: Product, selector: parsel.Selector = None):
